@@ -9,11 +9,14 @@ import (
 	"sort"
 	"strings"
 
+	goplugin "github.com/hashicorp/go-plugin"
+
 	"github.com/davecgh/go-spew/spew"
 	"github.com/posener/complete"
 	"github.com/zclconf/go-cty/cty"
 
 	"github.com/hashicorp/go-argmapper"
+	"github.com/hashicorp/go-hclog"
 	"github.com/hashicorp/hcl/v2"
 	"github.com/hashicorp/waypoint-plugin-sdk/component"
 	"github.com/hashicorp/waypoint-plugin-sdk/docs"
@@ -202,10 +205,15 @@ func (c *AppDocsCommand) emitField(w io.Writer, h, out string, f *docs.FieldDocs
 		parts = append(parts, list.String())
 	}
 
+	nh := h + "#"
+	if len(nh) > 6 {
+		nh = h
+	}
+
 	if sf := f.SubFields; len(sf) > 0 {
 		for _, f := range sf {
 			var sub bytes.Buffer
-			c.emitField(&sub, h+"#", name, f)
+			c.emitField(&sub, nh, name, f)
 			parts = append(parts, sub.String())
 		}
 	}
@@ -251,13 +259,18 @@ func (c *AppDocsCommand) emitSection(w io.Writer, name, use, h string, fields []
 	}
 
 	for i, f := range fields {
-		c.emitField(w, h+"#", "", f)
+		nh := h + "#"
+		if len(nh) > 6 {
+			nh = h
+		}
+
+		c.emitField(w, nh, "", f)
 		endingSpace(w, i, len(fields))
 	}
 }
 
 func (c *AppDocsCommand) mdxFormat(name, ct string, doc *docs.Documentation) {
-	// we use this constnat to compare to ct for some special behavior
+	// we use this constant to compare to ct for some special behavior
 	const csType = "configsourcer"
 
 	w, err := os.Create(fmt.Sprintf("./website/content/partials/components/%s-%s.mdx", ct, name))
@@ -420,96 +433,20 @@ func (c *AppDocsCommand) markdownFormatPB(name, ct string, doc *pb.Documentation
 	}
 }
 
-func (c *AppDocsCommand) builtinDocs(args []string) int {
-	types := []component.Type{
-		component.BuilderType,
-		component.RegistryType,
-		component.PlatformType,
-		component.ReleaseManagerType,
-		component.ConfigSourcerType,
-	}
-
-	docfactories := map[component.Type]*factory.Factory{}
-
-	for _, t := range types {
-		fact, err := factory.New(component.TypeMap[t])
-		if err != nil {
-			panic(err)
-		}
-
-		docfactories[t] = fact
-	}
-
-	for name := range plugin.Builtins {
-		for _, t := range types {
-			f := plugin.BuiltinFactory(name, t)
-			docfactories[t].Register(name, f)
-		}
-	}
-
-	factories := []struct {
-		f *factory.Factory
-		t string
-	}{
-		{docfactories[component.BuilderType], "builder"},
-		{docfactories[component.RegistryType], "registry"},
-		{docfactories[component.PlatformType], "platform"},
-		{docfactories[component.ReleaseManagerType], "releasemanager"},
-		{docfactories[component.ConfigSourcerType], "configsourcer"},
-	}
-
-	for _, f := range factories {
-		if c.flagType != "" && c.flagType != f.t {
-			continue
-		}
-
-		types := f.f.Registered()
-		sort.Strings(types)
-
-		for _, t := range types {
-			if c.flagPlugin != "" && c.flagPlugin != t {
-				continue
-			}
-
-			fn := f.f.Func(t)
-			res := fn.Call(argmapper.Typed(c.Log))
-			if res.Err() != nil {
-				panic(res.Err())
-			}
-
-			raw := res.Out(0)
-
-			// If we have a plugin.Instance then we can extract other information
-			// from this plugin. We accept pure factories too that don't return
-			// this so we type-check here.
-			if pinst, ok := raw.(*plugin.Instance); ok {
-				raw = pinst.Component
-				defer pinst.Close()
-			}
-
-			doc, err := component.Documentation(raw)
-			if err != nil {
-				continue
-			}
-
-			if c.flagMarkdown {
-				c.markdownFormat(t, f.t, doc)
-			} else {
-				c.basicFormat(t, f.t, doc)
-			}
-		}
-	}
-
-	return 0
+type pluginDocs struct {
+	pluginName string
+	pluginType string
+	doc        *docs.Documentation
 }
 
-func (c *AppDocsCommand) builtinMDX(args []string) int {
+func getDocs(builtinPluginNames []string, log hclog.Logger) ([]*pluginDocs, error) {
 	types := []component.Type{
 		component.BuilderType,
 		component.RegistryType,
 		component.PlatformType,
 		component.ReleaseManagerType,
 		component.ConfigSourcerType,
+		component.TaskLauncherType,
 	}
 
 	docfactories := map[component.Type]*factory.Factory{}
@@ -517,19 +454,45 @@ func (c *AppDocsCommand) builtinMDX(args []string) int {
 	for _, t := range types {
 		fact, err := factory.New(component.TypeMap[t])
 		if err != nil {
-			panic(err)
+			return nil, err
 		}
 
 		docfactories[t] = fact
 	}
 
-	for name := range plugin.Builtins {
-		for _, t := range types {
-			f := plugin.BuiltinFactory(name, t)
-			docfactories[t].Register(name, f)
+	// Look for any reattach plugins
+	var reattachPluginConfigs map[string]*goplugin.ReattachConfig
+	reattachPluginsStr := os.Getenv("WP_REATTACH_PLUGINS")
+	if reattachPluginsStr != "" {
+		var err error
+		reattachPluginConfigs, err = plugin.ParseReattachPlugins(reattachPluginsStr)
+		if err != nil {
+			return nil, err
 		}
 	}
 
+	for _, name := range builtinPluginNames {
+		_, ok := plugin.Builtins[name]
+		if !ok {
+			return nil, fmt.Errorf("Builtin plugin named %s does not exist", name)
+		}
+		if reattachConfig, ok := reattachPluginConfigs[name]; ok {
+			log.Debug(fmt.Sprintf("plugin %s is declared as running for reattachment", name))
+			for _, t := range types {
+				if err := docfactories[t].Register(name, plugin.ReattachPluginFactory(reattachConfig, t)); err != nil {
+					return nil, err
+				}
+			}
+			continue
+		} else {
+			for _, t := range types {
+				f := plugin.BuiltinFactory(name, t)
+				docfactories[t].Register(name, f)
+			}
+		}
+
+	}
+
 	factories := []struct {
 		f *factory.Factory
 		t string
@@ -539,17 +502,20 @@ func (c *AppDocsCommand) builtinMDX(args []string) int {
 		{docfactories[component.PlatformType], "platform"},
 		{docfactories[component.ReleaseManagerType], "releasemanager"},
 		{docfactories[component.ConfigSourcerType], "configsourcer"},
+		{docfactories[component.TaskLauncherType], "task"},
 	}
 
+	var requestedDocs []*pluginDocs
 	for _, f := range factories {
 		types := f.f.Registered()
 		sort.Strings(types)
 
 		for _, t := range types {
+
 			fn := f.f.Func(t)
-			res := fn.Call(argmapper.Typed(c.Log))
+			res := fn.Call(argmapper.Typed(log))
 			if res.Err() != nil {
-				panic(res.Err())
+				return nil, res.Err()
 			}
 
 			raw := res.Out(0)
@@ -565,20 +531,75 @@ func (c *AppDocsCommand) builtinMDX(args []string) int {
 
 			doc, err := component.Documentation(raw)
 			if err != nil {
-				cleanup()
-				panic(err.Error())
+				continue
 			}
 
-			switch f.t {
-			case "configsourcer":
-				c.mdxFormatConfigSourcer(t, f.t, doc)
-
-			default:
-				c.mdxFormat(t, f.t, doc)
-			}
+			requestedDocs = append(requestedDocs, &pluginDocs{
+				pluginName: t,
+				pluginType: f.t,
+				doc:        doc,
+			})
 			cleanup()
 		}
 	}
+	return requestedDocs, nil
+}
+
+func (c *AppDocsCommand) builtinDocs(args []string) int {
+	var pluginNames []string
+	if c.flagPlugin != "" {
+		pluginNames = append(pluginNames, c.flagPlugin)
+	} else {
+		// Use all plugins
+		for pluginName := range plugin.Builtins {
+			pluginNames = append(pluginNames, pluginName)
+		}
+	}
+
+	pluginDocs, err := getDocs(pluginNames, c.Log)
+	if err != nil {
+		c.ui.Output(fmt.Sprintf("Failed to get plugin docs: %s", err), terminal.StatusError)
+		return 1
+	}
+
+	for _, pluginDoc := range pluginDocs {
+		if c.flagMarkdown {
+			c.markdownFormat(pluginDoc.pluginName, pluginDoc.pluginType, pluginDoc.doc)
+		} else {
+			c.basicFormat(pluginDoc.pluginName, pluginDoc.pluginType, pluginDoc.doc)
+		}
+	}
+
+	return 0
+}
+
+func (c *AppDocsCommand) builtinMDX() int {
+
+	var pluginNames []string
+	if c.flagPlugin != "" {
+		pluginNames = append(pluginNames, c.flagPlugin)
+	} else {
+		// Use all plugins
+		for pluginName := range plugin.Builtins {
+			pluginNames = append(pluginNames, pluginName)
+		}
+	}
+
+	pluginDocs, err := getDocs(pluginNames, c.Log)
+	if err != nil {
+		c.ui.Output(fmt.Sprintf("Failed to get plugin docs: %s", err), terminal.StatusError)
+		return 1
+	}
+
+	for _, pluginDoc := range pluginDocs {
+		switch pluginDoc.pluginType {
+		case "configsourcer":
+			c.mdxFormatConfigSourcer(pluginDoc.pluginName, pluginDoc.pluginType, pluginDoc.doc)
+
+		default:
+			c.mdxFormat(pluginDoc.pluginName, pluginDoc.pluginType, pluginDoc.doc)
+		}
+	}
 
 	return c.funcsMDX()
 }
@@ -676,12 +697,19 @@ func (c *AppDocsCommand) Run(args []string) int {
 		return 1
 	}
 
+	if os.Getenv("WP_REATTACH_PLUGINS") != "" {
+		// Currently, only waypoint runners have the logic necessary to reattach to an existing plugin.
+		c.ui.Output("WP_REATTACH_PLUGINS detected, but plugin debugging is not supported with this command.", terminal.StatusError)
+		// Exit immediately, as an IDE user is unlikely to notice this warning otherwise
+		return 1
+	}
+
 	if c.flagBuiltin {
 		return c.builtinDocs(args)
 	}
 
 	if c.flagMDX {
-		return c.builtinMDX(args)
+		return c.builtinMDX()
 	}
 
 	err = c.DoApp(c.Ctx, func(ctx context.Context, app *clientpkg.App) error {
