@@ -16,7 +16,11 @@ import (
 type ConfigSetCommand struct {
 	*baseCommand
 
-	flagRunner bool
+	flagGlobal         bool
+	flagRunner         bool
+	flagScope          string
+	flagWorkspaceScope string
+	flagLabelScope     string
 }
 
 func (c *ConfigSetCommand) Run(args []string) int {
@@ -30,15 +34,20 @@ func (c *ConfigSetCommand) Run(args []string) int {
 	}
 
 	// We parse our flags twice in this command because we need to
-	// determine if we're setting runner config or not. If we're setting
-	// runner config, we don't need any Waypoint config.
+	// determine if we're loading a config or not.
 	//
 	// NOTE we specifically ignore errors here because if we have errors
 	// they'll happen again on Init and Init will output to the CLI.
-	if err := c.Flags().Parse(args); err == nil && c.flagRunner {
-		initOpts = append(initOpts,
-			WithNoConfig(), // no waypoint.hcl
-		)
+	if err := c.Flags().Parse(args); err == nil {
+		// If we're global scoped OR we have a project explicitly set
+		// then we do not need a config. If we're not global scoped and
+		// we do not have a project explicitly set, we need a config because
+		// we need a way to load that project name.
+		if c.flagScope == "global" || c.flagProject != "" {
+			initOpts = append(initOpts,
+				WithNoConfig(), // no waypoint.hcl
+			)
+		}
 	}
 
 	// Initialize. If we fail, we just exit since Init handles the UI.
@@ -67,6 +76,12 @@ func (c *ConfigSetCommand) Run(args []string) int {
 		}
 	}
 
+	// Pre-calculate our project ref since we reuse this.
+	projectRef := &pb.Ref_Project{Project: c.flagProject}
+	if c.flagProject == "" && c.project != nil {
+		projectRef = c.project.Ref()
+	}
+
 	// Get our API client
 	client := c.project.Client()
 
@@ -79,35 +94,60 @@ func (c *ConfigSetCommand) Run(args []string) int {
 			return 1
 		}
 
+		// Build our initial config var
 		configVar := &pb.ConfigVar{
-			Name: arg[:idx],
+			Target: &pb.ConfigVar_Target{},
+			Name:   arg[:idx],
 			Value: &pb.ConfigVar_Static{
 				Static: arg[idx+1:],
 			},
 		}
 
-		switch {
-		case c.flagRunner:
-			configVar.Scope = &pb.ConfigVar_Runner{
-				Runner: &pb.Ref_Runner{
-					Target: &pb.Ref_Runner_Any{
-						Any: &pb.Ref_RunnerAny{},
-					},
-				},
+		// Depending on the scoping set our target
+		switch c.flagScope {
+		case "global":
+			configVar.Target.AppScope = &pb.ConfigVar_Target_Global{
+				Global: &pb.Ref_Global{},
 			}
 
-		case c.flagApp == "":
-			configVar.Scope = &pb.ConfigVar_Project{
-				Project: c.project.Ref(),
+		case "project":
+			configVar.Target.AppScope = &pb.ConfigVar_Target_Project{
+				Project: projectRef,
 			}
 
-		default:
-			configVar.Scope = &pb.ConfigVar_Application{
+		case "app":
+			configVar.Target.AppScope = &pb.ConfigVar_Target_Application{
 				Application: &pb.Ref_Application{
-					Project:     c.project.Ref().Project,
+					Project:     projectRef.Project,
 					Application: c.flagApp,
 				},
 			}
+
+		default:
+			err := fmt.Errorf("-scope needs to be one of 'global', 'project', or 'app'")
+			c.project.UI.Output(clierrors.Humanize(err), terminal.WithErrorStyle())
+			return 1
+		}
+
+		// If we're targeting a runner, set that
+		if c.flagRunner {
+			configVar.Target.Runner = &pb.Ref_Runner{
+				Target: &pb.Ref_Runner_Any{
+					Any: &pb.Ref_RunnerAny{},
+				},
+			}
+		}
+
+		// If we have a workspace flag set, set that.
+		if v := c.flagWorkspaceScope; v != "" {
+			configVar.Target.Workspace = &pb.Ref_Workspace{
+				Workspace: v,
+			}
+		}
+
+		// If we have a label flag set, set that.
+		if v := c.flagLabelScope; v != "" {
+			configVar.Target.LabelSelector = v
 		}
 
 		req.Variables = append(req.Variables, configVar)
@@ -126,13 +166,42 @@ func (c *ConfigSetCommand) Flags() *flag.Sets {
 	return c.flagSet(0, func(set *flag.Sets) {
 		f := set.NewSet("Command Options")
 
+		f.StringVar(&flag.StringVar{
+			Name:   "scope",
+			Target: &c.flagScope,
+			Usage: "The scope for this configuration. The configuration will only " +
+				"appear within this scope. This can be one of 'global', 'project', or " +
+				"'app'.",
+			Default: "project",
+		})
+
+		f.StringVar(&flag.StringVar{
+			Name:   "workspace-scope",
+			Target: &c.flagWorkspaceScope,
+			Usage: "Specify that the configuration is only available within a " +
+				"specific workspace. This configuration will only be set for " +
+				"deployments or operations (if -runner if set) when the workspace " +
+				"matches this.",
+			Default: "",
+		})
+
+		f.StringVar(&flag.StringVar{
+			Name:   "label-scope",
+			Target: &c.flagLabelScope,
+			Usage: "If set, configuration will only be set if the deployment " +
+				"or operation (if -runner is set) has a matching label set.",
+			Default: "",
+		})
+
 		f.BoolVar(&flag.BoolVar{
 			Name:   "runner",
 			Target: &c.flagRunner,
 			Usage: "Expose this configuration on runners. This can be used " +
 				"to set things such as credentials to cloud platforms " +
 				"for remote runners. This configuration will not be exposed " +
-				"to deployed applications.",
+				"to deployed applications. If this is specified in the context " +
+				"of a project, this will apply only to runners operating on jobs " +
+				"for the specific project or application.",
 			Default: false,
 		})
 	})
@@ -158,6 +227,10 @@ Usage: waypoint config set <name>=<value>
   environment variable.
 
   This will scope the variable to the entire project by default.
+  Specify the "-project" flag to set a config variable for a specific project.
+  The "-project" flag is not required if scope is global or there is a local
+  waypoint.hcl file.
+
   Specify the "-app" flag to set a config variable for a specific app.
 
 ` + c.Flags().Help())
