@@ -116,13 +116,49 @@ func (c *InstallCommand) Run(args []string) int {
 	s := sg.Add("Connecting to: %s", contextConfig.Server.Address)
 	defer func() { s.Abort() }()
 
-	// Connect
-	log.Info("connecting to the server so we can set the server config", "addr", contextConfig.Server.Address)
-	conn, err := serverclient.Connect(ctx,
-		serverclient.FromContextConfig(contextConfig),
-		serverclient.Timeout(5*time.Minute),
-	)
-	if err != nil {
+	// Connect and retry for a full minute
+	var conn *grpc.ClientConn
+	retries := 0
+	maxRetries := 12
+	sr := sg.Add("Attempting to make connection to server...") // stepgroup for retry ui
+
+	for {
+		log.Info("connecting to the server so we can set the server config", "addr", contextConfig.Server.Address)
+		conn, err = serverclient.Connect(ctx,
+			serverclient.FromContextConfig(contextConfig),
+			serverclient.Timeout(5*time.Second),
+		)
+		if err != nil {
+			sr.Update(
+				"Error connecting to server: %s\n\n%s",
+				clierrors.Humanize(err),
+				errInstallRunning,
+			)
+			sr.Status(terminal.StatusError)
+			// dont return the error yet
+		} else {
+			sr.Update("Successfully connected to Waypoint server in %s!", strings.Title(c.platform))
+			sr.Status(terminal.StatusOK)
+			sr.Done()
+			break
+		}
+
+		if retries >= maxRetries {
+			sr.Update("Failed to connect to Waypoint server after max retry attempts of %d", maxRetries)
+			sr.Status(terminal.StatusError)
+			sr.Done()
+			break
+		}
+
+		// add ui output for iteration loop retry number
+		sr.Update("Retry connecting to server ... %d/%d retries: %s", retries, maxRetries, clierrors.Humanize(err))
+		sr.Status(terminal.StatusWarn)
+		time.Sleep(5 * time.Second)
+		retries++
+	}
+
+	if conn == nil && err != nil {
+		// raise error
 		c.ui.Output(
 			"Error connecting to server: %s\n\n%s",
 			clierrors.Humanize(err),
@@ -131,6 +167,7 @@ func (c *InstallCommand) Run(args []string) int {
 		)
 		return 1
 	}
+
 	client := pb.NewWaypointClient(conn)
 
 	s.Update("Retrieving initial auth token...")
@@ -491,8 +528,10 @@ func installRunner(
 
 			if err != nil {
 				s.Update("Error creating ondemand runner: %s", err)
+				s.Status(terminal.StatusError)
 			} else {
 				s.Update("Registered ondemand runner!")
+				s.Status(terminal.StatusOK)
 			}
 		} else {
 			s.Update("Install type did not provide an ondemand runner config")
