@@ -14,6 +14,7 @@ import (
 
 	"github.com/hashicorp/waypoint-plugin-sdk/terminal"
 	"github.com/hashicorp/waypoint/internal/pkg/flag"
+	"github.com/hashicorp/waypoint/internal/plugin"
 	runnerpkg "github.com/hashicorp/waypoint/internal/runner"
 	pb "github.com/hashicorp/waypoint/internal/server/gen"
 	"github.com/hashicorp/waypoint/internal/serverclient"
@@ -30,8 +31,21 @@ type RunnerAgentCommand struct {
 	// Specifies an address to setup a noop TCP server on that can be
 	// used for liveness probes.
 	flagLivenessTCPAddr string
+
+	// The specific ID that the runner should use. When not set, the runner
+	// generates an random.
+	flagId string
+
+	// This indicates that the runner is an on-demand runner. This information
+	// is made available to the plugins so they can alter their behavior for
+	// this unique context.
+	flagODR bool
 }
 
+// This is how long a runner in ODR mode will wait for its job assignment before
+// timing out.
+var defaultRunnerODRAcceptTimeout = 60 * time.Second
+
 func (c *RunnerAgentCommand) Run(args []string) int {
 	defer c.Close()
 	ctx := c.Ctx
@@ -47,6 +61,8 @@ func (c *RunnerAgentCommand) Run(args []string) int {
 		return 1
 	}
 
+	plugin.InsideODR = c.flagODR
+
 	// Connect to the server
 	log.Info("sourcing credentials and connecting to the Waypoint server")
 	conn, err := serverclient.Connect(ctx,
@@ -68,9 +84,15 @@ func (c *RunnerAgentCommand) Run(args []string) int {
 		{Name: "Server address", Value: conn.Target()},
 	})
 	c.ui.Output("Runner logs:", terminal.WithHeaderStyle())
+	if c.flagODR {
+		c.ui.Output("Operating as an On-demand Runner")
+	} else {
+		c.ui.Output("Operating as a static Runner")
+	}
+
 	c.ui.Output("")
 
-	// Set our log output higher if its not already so that it begins showing.
+	// Set our log output higher if it's not already so that it begins showing.
 	if !log.IsInfo() {
 		log.SetLevel(hclog.Info)
 	}
@@ -98,11 +120,26 @@ func (c *RunnerAgentCommand) Run(args []string) int {
 
 	// Create our runner
 	log.Info("initializing the runner")
-	runner, err := runnerpkg.New(
+
+	options := []runnerpkg.Option{
 		runnerpkg.WithClient(client),
 		runnerpkg.WithLogger(log.Named("runner")),
 		runnerpkg.WithDynamicConfig(c.flagDynConfig),
-	)
+	}
+
+	if c.flagId != "" {
+		options = append(options, runnerpkg.WithId(c.flagId))
+	}
+
+	if c.flagODR {
+		options = append(options,
+			runnerpkg.WithODR(),
+			runnerpkg.ByIdOnly(),
+			runnerpkg.WithAcceptTimeout(defaultRunnerODRAcceptTimeout),
+		)
+	}
+
+	runner, err := runnerpkg.New(options...)
 	if err != nil {
 		c.ui.Output(
 			"Error initializing the runner: %s", err.Error(),
@@ -112,7 +149,7 @@ func (c *RunnerAgentCommand) Run(args []string) int {
 	}
 
 	// Start the runner
-	log.Info("starting runner")
+	log.Info("starting runner", "id", runner.Id())
 	if err := runner.Start(); err != nil {
 		log.Error("error starting runner", "err", err)
 		return 1
@@ -153,15 +190,27 @@ func (c *RunnerAgentCommand) Run(args []string) int {
 
 	// Accept jobs in goroutine so that we can interrupt it.
 	ctx, cancel := context.WithCancel(ctx)
+
 	go func() {
 		defer cancel()
 
 		for {
-			if err := runner.Accept(ctx); err != nil {
+			err := runner.Accept(ctx)
+			if err == nil && c.flagODR {
+				log.Debug("handled our one job in ODR mode, exiting")
+				return
+			}
+
+			if err != nil {
 				if err == runnerpkg.ErrClosed {
 					return
 				}
 
+				if err == runnerpkg.ErrTimeout {
+					log.Error("timed out waiting for a job")
+					return
+				}
+
 				log.Error("error running job", "err", err)
 
 				switch status.Code(err) {
@@ -212,6 +261,18 @@ func (c *RunnerAgentCommand) Flags() *flag.Sets {
 				"address when it is running. This can be used as a liveness probe " +
 				"endpoint. The TCP server serves no other purpose.",
 		})
+
+		f.StringVar(&flag.StringVar{
+			Name:   "id",
+			Target: &c.flagId,
+			Usage:  "If this is set, the runner will use the specified id.",
+		})
+
+		f.BoolVar(&flag.BoolVar{
+			Name:   "odr",
+			Target: &c.flagODR,
+			Usage:  "Indicates to the runner it's operating as an on-demand runner.",
+		})
 	})
 }
 
