@@ -2,6 +2,8 @@ package singleprocess
 
 import (
 	"context"
+	"math/rand"
+	"reflect"
 	"time"
 
 	"github.com/golang/protobuf/ptypes"
@@ -16,6 +18,7 @@ import (
 	"github.com/hashicorp/waypoint/internal/server/logbuffer"
 	serverptypes "github.com/hashicorp/waypoint/internal/server/ptypes"
 	"github.com/hashicorp/waypoint/internal/server/singleprocess/state"
+	"github.com/hashicorp/waypoint/internal/serverconfig"
 )
 
 // TODO: test
@@ -90,7 +93,6 @@ func (s *service) queueJobMulti(
 	}
 
 	return resp, nil
-
 }
 
 // queueJobReqToJob converts a QueueJobRequest to a job to queue, but
@@ -99,6 +101,7 @@ func (s *service) queueJobReqToJob(
 	ctx context.Context,
 	req *pb.QueueJobRequest,
 ) (*pb.Job, error) {
+	log := hclog.FromContext(ctx)
 	job := req.Job
 
 	// Validation
@@ -116,6 +119,7 @@ func (s *service) queueJobReqToJob(
 	}
 
 	// Verify the project exists and use that to set the default data source
+	log.Debug("checking job project", "project", job.Application.Project)
 	project, err := s.state.ProjectGet(&pb.Ref_Project{Project: job.Application.Project})
 	if status.Code(err) == codes.NotFound {
 		return nil, status.Errorf(codes.NotFound,
@@ -160,6 +164,49 @@ func (s *service) queueJobReqToJob(
 		}
 	}
 
+	// If the job can be run any any runner, then we attempt to see if we should spawn
+	// on on-demand runner for it. We only consider jobs for any runner because ones
+	// that are targeted can not target on-demand runners, because they don't yet exist.
+	var od *pb.Ref_OnDemandRunnerConfig
+	if _, anyTarget := job.TargetRunner.Target.(*pb.Ref_Runner_Any); anyTarget {
+		od = project.OndemandRunner
+		if od == nil {
+			ods, err := s.state.OnDemandRunnerConfigDefault()
+			if err != nil {
+				return nil, err
+			}
+
+			switch len(ods) {
+			case 0:
+				// ok, no ondemand runners
+			case 1:
+				od = ods[0]
+			default:
+				od = ods[rand.Intn(len(ods))]
+				log.Debug("multiple default ondemand runners detected, chose a random one",
+					"runner-config-id", od.Id)
+			}
+		}
+	}
+
+	// If the job is targetted at any runner AND project has configuration for launching ondemand
+	// runners, then we dutifully launch an ondemand runner now. We'll also assign the job to this
+	// new runner now, so that it doesn't get picked up by other runners.
+	if od != nil {
+		runnerId, err := s.launchOnDemandRunner(ctx, job, project, od)
+		if err != nil {
+			return nil, err
+		}
+
+		job.TargetRunner = &pb.Ref_Runner{
+			Target: &pb.Ref_Runner_Id{
+				Id: &pb.Ref_RunnerId{
+					Id: runnerId,
+				},
+			},
+		}
+	}
+
 	return job, nil
 }
 
@@ -180,6 +227,133 @@ func (s *service) QueueJob(
 	return &pb.QueueJobResponse{JobId: job.Id}, nil
 }
 
+func (s *service) launchOnDemandRunner(
+	ctx context.Context,
+	source *pb.Job,
+	project *pb.Project,
+	odref *pb.Ref_OnDemandRunnerConfig,
+) (string, error) {
+	log := hclog.FromContext(ctx)
+
+	od, err := s.state.OnDemandRunnerConfigGet(odref)
+	if err != nil {
+		return "", err
+	}
+
+	runnerId, err := server.Id()
+	if err != nil {
+		return "", err
+	}
+
+	log.Info("requesting ondemand runner via task start", "runner-id", runnerId)
+
+	// Get our server config
+	cfg, err := s.state.ServerConfigGet()
+	if err != nil {
+		return "", err
+	}
+
+	// Follow the same logic as RunnerGetDeploymentConfig, which includes this note:
+	// Our addr for now is just the first one since we don't support
+	// multiple addresses yet. In the future we will want to support more
+	// advanced choicing.
+
+	var addr *pb.ServerConfig_AdvertiseAddr
+
+	// This should only happen during tests
+	if len(cfg.AdvertiseAddrs) == 0 {
+		log.Info("server has no advertise addrs, using localhost")
+		addr = &pb.ServerConfig_AdvertiseAddr{
+			Addr: "localhost:9701",
+		}
+	} else {
+		addr = cfg.AdvertiseAddrs[0]
+	}
+
+	// We generate a new login token for each ondemand-runner used. This will inherit
+	// the user of the token to be the user that queue'd the original job, which is
+	// the correct behavior.
+	token, err := s.newToken(60*time.Minute, DefaultKeyId, nil, &pb.Token{
+		Kind: &pb.Token_Login_{Login: &pb.Token_Login{
+			UserId: DefaultUserId,
+		}},
+	})
+	if err != nil {
+		return "", err
+	}
+
+	scfg := serverconfig.Client{
+		Address:       addr.Addr,
+		Tls:           addr.Tls,
+		TlsSkipVerify: addr.TlsSkipVerify,
+		RequireAuth:   true,
+		AuthToken:     token,
+	}
+
+	envVars := scfg.EnvMap()
+	envVars["WAYPOINT_RUNNER_ID"] = runnerId
+
+	for k, v := range od.EnvironmentVariables {
+		envVars[k] = v
+	}
+
+	args := []string{"runner", "agent", "-vv", "-id", runnerId, "-odr"}
+
+	job := &pb.Job{
+		Workspace:   source.Workspace,
+		Application: source.Application,
+		Operation: &pb.Job_StartTask{
+			StartTask: &pb.Job_StartTaskLaunchOp{
+				Params: &pb.Job_TaskPluginParams{
+					PluginType: od.PluginType,
+					HclConfig:  od.PluginConfig,
+					HclFormat:  od.ConfigFormat,
+				},
+				Info: &pb.TaskLaunchInfo{
+					OciUrl:               od.OciUrl,
+					EnvironmentVariables: envVars,
+					Arguments:            args,
+				},
+			},
+		},
+	}
+
+	// Get the next id
+	id, err := server.Id()
+	if err != nil {
+		return "", status.Errorf(codes.Internal, "uuid generation failed: %s", err)
+	}
+	job.Id = id
+
+	// We're going to wait up to 60s for the job be picked up. No reason it won't be
+	// picked up immediately.
+	dur, err := time.ParseDuration("60s")
+	if err != nil {
+		return "", status.Errorf(codes.FailedPrecondition,
+			"Invalid expiry duration: %s", err.Error())
+	}
+
+	job.ExpireTime, err = ptypes.TimestampProto(time.Now().Add(dur))
+	if err != nil {
+		return "", status.Errorf(codes.Aborted, "error configuring expiration: %s", err)
+	}
+
+	job.TargetRunner = &pb.Ref_Runner{
+		Target: &pb.Ref_Runner_Any{
+			Any: &pb.Ref_RunnerAny{},
+		},
+	}
+
+	// Queue the job
+	if err := s.state.JobCreate(job); err != nil {
+		return "", err
+	}
+
+	log.Debug("queue'd task to start on-demand runner", "job-id", job.Id, "runner-id", runnerId)
+
+	return runnerId, nil
+}
+
 func (s *service) ValidateJob(
 	ctx context.Context,
 	req *pb.ValidateJobRequest,
@@ -273,6 +447,7 @@ func (s *service) GetJobStream(
 
 	// Enter the event loop
 	var lastState pb.Job_State
+	var lastJob *pb.Job
 	var eventsCh <-chan []*pb.GetJobStreamResponse_Terminal_Event
 	for {
 		select {
@@ -321,6 +496,25 @@ func (s *service) GetJobStream(
 				downloadSent = true
 			}
 
+			// If our job changed then we send down a job change notification.
+			// We use reflect.DeepEqual here which isn't super exact but errors
+			// on the side of false positives rather than false negatives so
+			// at worst it'll send down a few more noisy job updates rather than
+			// miss any. Because of this, we use it for simplicity.
+			if lastJob == nil || !reflect.DeepEqual(lastJob, job.Job) {
+				lastJob = job.Job
+
+				if err := server.Send(&pb.GetJobStreamResponse{
+					Event: &pb.GetJobStreamResponse_Job{
+						Job: &pb.GetJobStreamResponse_JobChange{
+							Job: job.Job,
+						},
+					},
+				}); err != nil {
+					return err
+				}
+			}
+
 			// If we haven't initialized output streaming and the output buffer
 			// is now non-nil, initialize that. This will send any buffered
 			// data down.
