@@ -40,4 +40,16 @@ export default Factory.extend({
       server.create('health', 'partial', { statusReport });
     },
   }),
+
+  'with-deployment-resources': trait({
+    afterCreate(statusReport, server) {
+      server.create('resource', 'random-deployment', { statusReport });
+    },
+  }),
+
+  'with-release-resources': trait({
+    afterCreate(statusReport, server) {
+      server.create('resource', 'random-service', { statusReport });
+    },
+  }),
 });
