@@ -1,13 +1,13 @@
-import { Request, Response } from 'miragejs';
+import { RouteHandler, Request, Response } from 'miragejs';
 import { ListPushedArtifactsRequest, ListPushedArtifactsResponse } from 'waypoint-pb';
 import { decode } from '../helpers/protobufs';
 
 // eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types, @typescript-eslint/no-explicit-any
-export function list(schema: any, request: Request): Response {
+export function list(this: RouteHandler, schema: any, request: Request): Response {
   let requestMsg = decode(ListPushedArtifactsRequest, request.requestBody);
-  let projectName = requestMsg.getApplication().getProject();
-  let appName = requestMsg.getApplication().getApplication();
-  let workspaceName = requestMsg.getWorkspace().getWorkspace();
+  let projectName = requestMsg.getApplication()?.getProject();
+  let appName = requestMsg.getApplication()?.getApplication();
+  let workspaceName = requestMsg.getWorkspace()?.getWorkspace();
   let project = schema.projects.findBy({ name: projectName });
   let application = schema.applications.findBy({ name: appName, projectId: project.id });
   let workspace = schema.workspaces.findBy({ name: workspaceName });
