@@ -38,7 +38,7 @@ module('Integration | Component | project-input-variables-list', function (hooks
     this.set('project', project.toObject());
 
     await render(hbs`<ProjectInputVariables::List @project={{this.project}}/>`);
-    assert.dom('.project-input-variables-list').exists('The list renders');
+    assert.dom('.variables-list').exists('The list renders');
     assert.equal(page.variablesList.length, 3, 'the list contains all variables');
     assert.notOk(page.variablesList.objectAt(0).isHcl, 'the list contains a string variable');
     assert.ok(page.variablesList.objectAt(2).isHcl, 'the list contains a hcl variable');
@@ -50,7 +50,7 @@ module('Integration | Component | project-input-variables-list', function (hooks
     this.set('project', project.toObject());
 
     await render(hbs`<ProjectInputVariables::List @project={{this.project}}/>`);
-    assert.dom('.project-input-variables-list').exists('The list renders');
+    assert.dom('.variables-list').exists('The list renders');
     assert.equal(page.variablesList.length, 3, 'the list contains all variables');
     await page.createButton();
     assert.ok(page.hasForm, 'Attempt to create: the form appears when the Add Variable button is clicked');
@@ -76,7 +76,7 @@ module('Integration | Component | project-input-variables-list', function (hooks
     this.set('project', project.toObject());
 
     await render(hbs`<ProjectInputVariables::List @project={{this.project}}/>`);
-    assert.dom('.project-input-variables-list').doesNotExist('the list is empty initially');
+    assert.dom('.variables-list').doesNotExist('the list is empty initially');
     assert.equal(page.variablesList.length, 0, 'the list contains no variables');
     await page.createButton();
     assert.ok(page.hasForm), 'Attempt to create: the form appears when the Add Variable button is clicked';
